"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Interceptor = void 0;
const msw_1 = require("msw");
const Methods_1 = require("./Methods");
class Interceptor {
    constructor(tables) {
        this.tables = tables;
        this.interceptorMethods = new Methods_1.Methods();
    }
    initialize() {
        const handlers = this.generateEndpoints();
        const worker = msw_1.setupWorker(...handlers);
        worker.start();
    }
    generateEndpoints() {
        const handlerArray = [];
        for (const table of this.tables) {
            const endPoints = this.getEndpoints(table);
            handlerArray.push(...endPoints);
        }
        return handlerArray;
    }
    getEndpoints(tableName) {
        return [
            msw_1.rest.post(`/api/${tableName}`, (req, res, ctx) => __awaiter(this, void 0, void 0, function* () {
                const response = yield this.interceptorMethods.create(tableName, req.body, req.method);
                return res(ctx.json(response));
            })),
            // GET ALL DATA
            msw_1.rest.get(`/api/${tableName}`, (req, res, ctx) => __awaiter(this, void 0, void 0, function* () {
                const response = yield this.interceptorMethods.getAll(tableName);
                return res(ctx.json(response));
            })),
            // GET DATA BY ID
            msw_1.rest.get(`/api/${tableName}/:id`, (req, res, ctx) => __awaiter(this, void 0, void 0, function* () {
                const response = yield this.interceptorMethods.getById(tableName, parseInt(req.params.id, 10));
                return res(ctx.json(response));
            })),
            msw_1.rest.put(`/api/${tableName}/:id`, (req, res, ctx) => __awaiter(this, void 0, void 0, function* () {
                const response = yield this.interceptorMethods.update(tableName, req.body, parseInt(req.params.id, 10), req.method);
                return res(ctx.json(response));
            })),
            msw_1.rest.delete(`/api/${tableName}/:id`, (req, res, ctx) => __awaiter(this, void 0, void 0, function* () {
                const response = yield this.interceptorMethods.delete(tableName, parseInt(req.params.id, 10));
                return res(ctx.json(response));
            })),
        ];
    }
}
exports.Interceptor = Interceptor;
//# sourceMappingURL=index.js.map