"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const moment_1 = __importDefault(require("moment"));
const constants_1 = require("../constants");
const dataType = {
    isString(value) {
        return typeof value === constants_1.DATA_TYPE.STRING;
    },
    isInteger(value) {
        return !isNaN(value) && Number.isInteger(value);
    },
    isFloat(value) {
        return (typeof value !== constants_1.DATA_TYPE.STRING && !isNaN(value) && Math.round(value) !== value);
    },
    isJson(value) {
        try {
            const isJsonString = JSON.parse(value);
            if (isJsonString && typeof isJsonString === constants_1.DATA_TYPE.OBJECT) {
                return true;
            }
        }
        catch (e) {
            return false;
        }
    },
    isDecimal(value) {
        return typeof value !== constants_1.DATA_TYPE.STRING && value - Math.floor(value) !== 0;
    },
    isBoolean(value) {
        return typeof value === constants_1.DATA_TYPE.BOOLEAN;
    },
    isDate(value) {
        return moment_1.default(value, constants_1.DATA_TYPE.DATE_FORMAT, true).isValid();
    },
    isDateTime(value) {
        return moment_1.default(value, constants_1.DATA_TYPE.DATE_TIME_FORMAT, true).isValid();
    },
    isTime(value) {
        return moment_1.default(value, constants_1.DATA_TYPE.TIME_FORMAT, true).isValid();
    },
    isTimestamp(value) {
        return moment_1.default(value, constants_1.DATA_TYPE.TIMESTAMP_FORMAT, true).isValid();
    },
};
exports.default = dataType;
//# sourceMappingURL=data-types.js.map